2023-08-22 Version: 1.0.8
- Generated python2 2021-09-01 for appstream-center.

2023-05-09 Version: 1.0.7
- Modify ListAppInstance.

2023-04-03 Version: 1.0.6
- Add ListAppInstances Open API.

2023-03-22 Version: 1.0.5
- Add ListAppInstances Open API.

2023-03-21 Version: 1.0.4
- Add Unbind Open API.

2023-03-10 Version: 1.0.3
- Add Unbind Open API.

2023-03-09 Version: 1.0.2
- Add GetConnectionTicket Open API.

2023-01-30 Version: 1.0.1
- For new api version.

2022-11-01 Version: 1.0.0
- For new api version.

